ecommerce plugin for `Grvlms <https://docs.grvlms.groove.education>`__
===================================================================================

Installation
------------

::

    pip install git+https://github.com/groovetch/grvlms-discovery

Usage
-----

::

    grvlms plugins enable discovery
    

License
-------

This software is licensed under the terms of the AGPLv3.